@@ -11,7 +11,7 @@
 			This is a game project which targets the ultimate city
 		simulation just like like xxxCity or something like that :)
 
-	$Id: main.cpp 451 2010-12-11 12:05:23Z neoneurone $
+	$Id: main.cpp 425 2009-11-01 16:38:58Z neoneurone $
  ***************************************************************************/
 
 /***************************************************************************
@@ -76,6 +76,10 @@ extern GlobalVar gVars;
 #include "property.h"
 #include "propertymanager2.h"
 
+// Test Sharp Plus Framework
+#include "framework/System/CString.h"
+#include "framework/System/Information/Software/CSdl.h"
+
 
    /*=====================================================================*/
    /*                           LOCAL     MACROS                          */
@@ -294,6 +298,10 @@ static int initSDL()
 // Initialization of the SDL library
 	OPENCITY_DEBUG( "SDL Initialization" );
 
+// Test Sharp Plus Framework
+	OPENCITY_INFO( "SDL compile-time version: " << System::Information::Software::Sdl::GetCompiletimeVersion() );
+	OPENCITY_INFO( "SDL run-time version: " << System::Information::Software::Sdl::GetRuntimeVersion() );
+
 // First, initialize SDL's video subsystem.
 	if( SDL_Init( SDL_INIT_VIDEO ) < 0 ) {
 		// Failed, exit.
