@@ -1,12 +1,12 @@
 /***************************************************************************
-						role.h  -  description
+                          role.h  -  description
 							-------------------
 	begin                : nov 29th 2005
-	copyright            : (C) 2005-2008 by Duong Khang NGUYEN
+	copyright            : (C) 2005-2010 by Duong Khang NGUYEN
 	email                : neoneurone @ gmail com
 	author               : Victor STINNER
 
-	$Id: role.h 375 2008-10-28 14:47:15Z neoneurone $
+	$Id: role.h 448 2010-05-09 15:18:32Z neoneurone $
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,57 +19,25 @@
  ***************************************************************************/
 
 
-#ifndef _OPENCITY_ROLE_H_
-#define _OPENCITY_ROLE_H_ 1
-
+#ifndef _OPENCITY_MAS_ROLE_H_
+#define _OPENCITY_MAS_ROLE_H_ 1
 
    /*=====================================================================*/
-typedef enum {
+enum MAS_ROLE
+{
 	ROLE_POLICE = 0,
 	ROLE_DEMONSTRATOR,
 	ROLE_ROBBER
-} MAS_ROLE;
+};
 
 
    /*=====================================================================*/
-typedef enum
+enum MAS_DIRECTION
 {
 	NORTH = 0,
 	WEST,
 	SOUTH,
 	EAST
-} MAS_DIRECTION;
+};
+
 #endif
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
