@@ -5,7 +5,7 @@
 	copyright            : (C) 2003-2008 by Duong Khang NGUYEN
 	email                : neoneurone @ gmail com
 
-	$Id: renderer.cpp 375 2008-10-28 14:47:15Z neoneurone $
+	$Id: renderer.cpp 450 2010-11-21 19:11:43Z neoneurone $
  ***************************************************************************/
 
 /***************************************************************************
@@ -1170,7 +1170,7 @@ Renderer::_DisplayTerrain() const
 	if (bHeightChange == false)
 		goto displayterrain_return;
 
-	static OC_BYTE tabH[4];				// Terrain height
+	static signed char tabH[4];			// Terrain height
 	static GLfloat tabR[4];				// Texture R (depth) coordinate
 	static GLfloat ax, ay, az;
 	static GLfloat bx, by, bz;
