@@ -5,7 +5,7 @@
 	copyright            : (C) 2004 by Duong Khang NGUYEN
 	email                : neoneurone @ gmail com
 
-	$Id: industrialsim.h 375 2008-10-28 14:47:15Z neoneurone $
+	$Id: industrialsim.h 450 2010-11-21 19:11:43Z neoneurone $
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,16 +18,16 @@
  ***************************************************************************/
 
 #ifndef _OPENCITY_INDUSTRIALSIM_H_
-	#define _OPENCITY_INDUSTRIALSIM_H_ 1
+#define _OPENCITY_INDUSTRIALSIM_H_ 1
 
-	#include "main.h"
-
-	#include "simulator.h"
+#include "main.h"
+#include "simulator.h"
 
 
-   /** This class handles the simulation of industrial zones
-   */
-class IndustrialSim : public Simulator  {
+/** This class handles the simulation of industrial zones
+*/
+class IndustrialSim : public Simulator
+{
 public:
 	IndustrialSim(
 		SDL_mutex* mutex,
@@ -49,38 +49,3 @@ public:
 };
 
 #endif
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
